// -*- C++ -*-

/* 
 * GChemPaint
 * mendeleiev.h 
 *
 * Copyright (C) 2001-2003
 *
 * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
 *
 * This program is free software; you can redistribute it and/or 
 * modify it under the terms of the GNU General Public License as 
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef GCHEMPAINT_MENDELEIEV_H
#define GCHEMPAINT_MENDELEIEV_H

#include "dialog.h"
#ifdef GCU_OLD_VER
#	include <gtkperiodic/gtkperiodic.h>
#else
#	include <gcu/gtkperiodic.h>
#endif

class gcpMendeleievDlg: public gcpDialog
{
public:
	gcpMendeleievDlg(int Z = 0);
	virtual ~gcpMendeleievDlg();
	
	void OnElement(int Z);
	void SetCallBack(void (*f)(int));
	
private:
//	GtkWidget* m_button;
	int m_Z;
	void (*apply)(int);
	GtkPeriodic* periodic;
};

extern int CurZ;
extern GtkCheckMenuItem* MendeleievMenu;
extern gcpMendeleievDlg *MendeleievDlg;

#endif // GCHEMPAINT_MENDELEIEV_H
